@@ -29,8 +29,7 @@ async def main():
                 break
     # should be ~1sec rather than ~50s due to async scheduling
     for i in tqdm.as_completed([asyncio.sleep(0.01 * i)
-                                for i in range(100, 0, -1)],
-                               desc="as_completed"):
+                                for i in range(100, 0, -1)], desc="as_completed"):
         await i
 
 
