@@ -5,127 +5,47 @@ from functools import wraps
 from warnings import warn
 import os
 import re
-import sys
 import subprocess
+import sys
+
+# py2/3 compat
+try:
+    _range = xrange
+except NameError:
+    _range = range
+
+try:
+    _unich = unichr
+except NameError:
+    _unich = chr
+
+try:
+    _unicode = unicode
+except NameError:
+    _unicode = str
+
+try:
+    _basestring = basestring
+except NameError:
+    _basestring = str
 
 CUR_OS = sys.platform
 IS_WIN = any(CUR_OS.startswith(i) for i in ['win32', 'cygwin'])
 IS_NIX = any(CUR_OS.startswith(i) for i in ['aix', 'linux', 'darwin'])
 RE_ANSI = re.compile(r"\x1b\[[;\d]*[A-Za-z]")
 
-
-# Py2/3 compat. Empty conditional to avoid coverage
-if True:  # pragma: no cover
-    try:
-        _range = xrange
-    except NameError:
-        _range = range
-
-    try:
-        _unich = unichr
-    except NameError:
-        _unich = chr
-
-    try:
-        _unicode = unicode
-    except NameError:
-        _unicode = str
-
-    try:
-        if IS_WIN:
-            import colorama
-        else:
-            raise ImportError
-    except ImportError:
-        colorama = None
+try:
+    if IS_WIN:
+        import colorama
     else:
-        try:
-            colorama.init(strip=False)
-        except TypeError:
-            colorama.init()
-
+        raise ImportError
+except ImportError:
+    colorama = None
+else:
     try:
-        from weakref import WeakSet
-    except ImportError:
-        WeakSet = set
-
-    try:
-        _basestring = basestring
-    except NameError:
-        _basestring = str
-
-    try:  # py>=2.7,>=3.1
-        from collections import OrderedDict as _OrderedDict
-    except ImportError:
-        try:  # older Python versions with backported ordereddict lib
-            from ordereddict import OrderedDict as _OrderedDict
-        except ImportError:  # older Python versions without ordereddict lib
-            # Py2.6,3.0 compat, from PEP 372
-            from collections import MutableMapping
-
-            class _OrderedDict(dict, MutableMapping):
-                # Methods with direct access to underlying attributes
-                def __init__(self, *args, **kwds):
-                    if len(args) > 1:
-                        raise TypeError('expected at 1 argument, got %d',
-                                        len(args))
-                    if not hasattr(self, '_keys'):
-                        self._keys = []
-                    self.update(*args, **kwds)
-
-                def clear(self):
-                    del self._keys[:]
-                    dict.clear(self)
-
-                def __setitem__(self, key, value):
-                    if key not in self:
-                        self._keys.append(key)
-                    dict.__setitem__(self, key, value)
-
-                def __delitem__(self, key):
-                    dict.__delitem__(self, key)
-                    self._keys.remove(key)
-
-                def __iter__(self):
-                    return iter(self._keys)
-
-                def __reversed__(self):
-                    return reversed(self._keys)
-
-                def popitem(self):
-                    if not self:
-                        raise KeyError
-                    key = self._keys.pop()
-                    value = dict.pop(self, key)
-                    return key, value
-
-                def __reduce__(self):
-                    items = [[k, self[k]] for k in self]
-                    inst_dict = vars(self).copy()
-                    inst_dict.pop('_keys', None)
-                    return self.__class__, (items,), inst_dict
-
-                # Methods with indirect access via the above methods
-                setdefault = MutableMapping.setdefault
-                update = MutableMapping.update
-                pop = MutableMapping.pop
-                keys = MutableMapping.keys
-                values = MutableMapping.values
-                items = MutableMapping.items
-
-                def __repr__(self):
-                    pairs = ', '.join(map('%r: %r'.__mod__, self.items()))
-                    return '%s({%s})' % (self.__class__.__name__, pairs)
-
-                def copy(self):
-                    return self.__class__(self)
-
-                @classmethod
-                def fromkeys(cls, iterable, value=None):
-                    d = cls()
-                    for key in iterable:
-                        d[key] = value
-                    return d
+        colorama.init(strip=False)
+    except TypeError:
+        colorama.init()
 
 
 class FormatReplace(object):
@@ -234,11 +154,11 @@ class DisableOnWriteError(ObjectWrapper):
     def __init__(self, wrapped, tqdm_instance):
         super(DisableOnWriteError, self).__init__(wrapped)
         if hasattr(wrapped, 'write'):
-            self.wrapper_setattr('write', self.disable_on_exception(
-                tqdm_instance, wrapped.write))
+            self.wrapper_setattr(
+                'write', self.disable_on_exception(tqdm_instance, wrapped.write))
         if hasattr(wrapped, 'flush'):
-            self.wrapper_setattr('flush', self.disable_on_exception(
-                tqdm_instance, wrapped.flush))
+            self.wrapper_setattr(
+                'flush', self.disable_on_exception(tqdm_instance, wrapped.flush))
 
     def __eq__(self, other):
         return self._wrapped == getattr(other, '_wrapped', other)
@@ -273,9 +193,9 @@ class CallbackIOWrapper(ObjectWrapper):
 def _is_utf(encoding):
     try:
         u'\u2588\u2589'.encode(encoding)
-    except UnicodeEncodeError:  # pragma: no cover
+    except UnicodeEncodeError:
         return False
-    except Exception:  # pragma: no cover
+    except Exception:
         try:
             return encoding.lower().startswith('utf-') or ('U8' == encoding)
         except:
@@ -398,8 +318,7 @@ except ImportError:
     _text_width = len
 else:
     def _text_width(s):
-        return sum(
-            2 if east_asian_width(ch) in 'FW' else 1 for ch in _unicode(s))
+        return sum(2 if east_asian_width(ch) in 'FW' else 1 for ch in _unicode(s))
 
 
 def disp_len(data):
